@@ -1,4 +1,4 @@
-/* $Id: gdict-about.c,v 1.9 2002/04/29 01:06:10 gman Exp $ */
+/* $Id: gdict-about.c,v 1.12 2002/07/22 13:52:25 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -53,11 +53,11 @@ static GtkWidget *gdict_about_new (void)
     
     g_free (file);    
     
-    about = gnome_about_new ("GNOME Dictionary", VERSION,
-                             "Copyright 1999 by Mike Hughes",
-                             _("Client for MIT dictionary server.\n"
-			    "Web: http://gdict.dhs.org/, "
-			    "http://www.psilord.com/code/"),
+    about = gnome_about_new (_("GNOME Dictionary"), VERSION,
+                            _("Copyright 1999 by Mike Hughes"),
+                            _("Client for MIT dictionary server.\n"
+			      "Web: http://gdict.dhs.org/, "
+			      "http://www.psilord.com/code/"),
 			     (const char **)authors,
 			     (const char **)documenters,
 			     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -66,16 +66,17 @@ static GtkWidget *gdict_about_new (void)
     	   gdk_pixbuf_unref (pixbuf);
     }
 
-    gtk_window_set_wmclass (GTK_WINDOW (about), "gdict", "GNOME Dictionary");
     gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gdict.png");				     
 			     
     return about;
 }
 
-void gdict_about (void)
+void gdict_about (GtkWindow *parent)
 {
     GtkWidget *about = gdict_about_new();
-
+    if (parent) {
+      gtk_window_set_transient_for (GTK_WINDOW (about), parent) ;
+    }
     gtk_widget_show(about);
 }
 
